SystemOrganization addCategory: #'Database-Abstraction-Layer'!

!UndefinedObject methodsFor: '*Database-Abstraction-Layer' stamp: 'JohanBrichau 8/19/2011 22:13'!
isDALObject 
	^ true! !

Object subclass: #DALAbstractDAO
	instanceVariableNames: 'session'
	classVariableNames: 'Current'
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'ThomasCleenewerck 2/8/2011 16:11'!
createBinaryFileStream: aPath
	^self sessionClass createBinaryFileStream: aPath  ! !

!DALAbstractDAO class methodsFor: 'creation' stamp: 'JohanBrichau 12/7/2010 16:02'!
createDatabaseConnection
	| dao |
	dao := self basicNew.
	dao initializeWithSession: (self sessionClass onDAO: dao).
	^ dao! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:42'!
createDictionary 
	^self sessionClass createDictionary ! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:42'!
createMatrix 
	^self sessionClass createMatrix! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:42'!
createOrderedCollection
	^ self sessionClass createOrderedCollection ! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:39'!
createRcDictionary 
	^self sessionClass createRcDictionary ! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:40'!
createRcOrderedCollection
	^ self sessionClass createRcOrderedCollection ! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:40'!
createRcSet 
	^ self sessionClass createRcSet! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 15:50'!
createSet 
	^ self sessionClass createSet! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 4/21/2011 11:11'!
createVersionStamp
	^ self sessionClass createVersionStamp! !

!DALAbstractDAO class methodsFor: 'singleton' stamp: 'JohanBrichau 11/2/2010 15:51'!
current
	Current ifNil:[self error:'No concrete DAO implementation has been set.'].
	^Current! !

!DALAbstractDAO class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:44'!
databaseException 
	^ self sessionClass databaseException! !

!DALAbstractDAO class methodsFor: 'singleton' stamp: 'AndyKellens 10/23/2010 14:29'!
new
	self shouldNotImplement ! !

!DALAbstractDAO class methodsFor: 'db actions' stamp: 'JohanBrichau 1/26/2011 12:43'!
reinitializeDatabase
	| db |
	"(re)initialize the database"
	db := self basicNew.
	db privateSession: (self sessionClass onDAO: db).
	db createDatabaseStructure.
	db disconnect! !

!DALAbstractDAO class methodsFor: 'configuration' stamp: 'JohanBrichau 12/7/2010 14:44'!
sessionClass
	self subclassResponsibility ! !

!DALAbstractDAO class methodsFor: 'singleton' stamp: 'JohanBrichau 11/2/2010 15:51'!
setAsCurrent
	Current := self! !

!DALAbstractDAO methodsFor: 'dal-importexport' stamp: 'JohanBrichau 1/12/2011 13:06'!
addShapeChangersTo: aSixxStream
	"override when needed"! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'JohanBrichau 12/7/2010 17:27'!
bringUpToDate
	^ session bringUpToDate ! !

!DALAbstractDAO methodsFor: 'db operations' stamp: 'AndyKellens 02/17/2011 19:10'!
createDatabaseStructure 
	"Initialize the database"
	session executeAsTransaction: [
		self root: self class createDictionary.
		self root at:#UniqueIdentifier put: (DALObjectIDCounter new).
		self root at:#ObjectHash put:(self class createRcDictionary).
		Current := self class. "this ensures the right DAO is set - without doing anything else"
		(self databaseStructure: session class createDictionary) 
			keysAndValuesDo: [:key :value | self root at: key put: value]].
	"Perform the bootstrapping process"
	self bootstrapDatabase! !

!DALAbstractDAO methodsFor: 'initialization' stamp: 'JohanBrichau 1/26/2011 12:43'!
databaseStructure: aDictionary 
	"Override in subclasses to create a fresh db structure (in the given dictionary)"
	^aDictionary ! !

!DALAbstractDAO methodsFor: 'db operations' stamp: 'AndyKellens 12/14/2010 20:42'!
disconnect
 	session disconnect! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'JohanBrichau 12/7/2010 17:27'!
executeAsTransaction: aBlock
	^ session executeAsTransaction: aBlock! !

!DALAbstractDAO methodsFor: 'dal-importexport' stamp: 'JohanBrichau 12/6/2010 16:55'!
exportTo: aFileName
	| sws |
	sws := SixxWriteStream newFileNamed: aFileName.
	sws nextPut: (self objectsToExport).
	sws close.! !

!DALAbstractDAO methodsFor: 'dal-importexport' stamp: 'JohanBrichau 1/12/2011 15:25'!
importFrom: aFileName
	| srs objects |
	srs := SixxReadStream readOnlyFileNamed: (aFileName).
	self addShapeChangersTo: srs.
	objects := OrderedCollection new.
	[srs atEnd] whileFalse: [objects add: srs next].
	srs close.
	self executeAsTransaction: [self importObjects: objects]! !

!DALAbstractDAO methodsFor: 'dal-importexport' stamp: 'JohanBrichau 12/6/2010 16:54'!
importObjects: objects
	self subclassResponsibility ! !

!DALAbstractDAO methodsFor: 'private' stamp: 'JohanBrichau 12/7/2010 16:09'!
increaseUniqueIdentifier 
	^ session increaseUniqueIdentifier! !

!DALAbstractDAO methodsFor: 'initialization' stamp: 'AndyKellens 8/14/2011 16:36'!
initializeWithSession: aSession 
	"Initialize this DAO with the concrete session"
	self privateSession: aSession! !

!DALAbstractDAO methodsFor: 'transactions abstract' stamp: 'JohanBrichau 8/19/2011 22:13'!
isPersistentObject: anObject 
	^ anObject isDALObject! !

!DALAbstractDAO methodsFor: 'testing' stamp: 'JohanBrichau 3/20/2011 15:46'!
isSegmentedDAO
	^ false! !

!DALAbstractDAO methodsFor: 'dal-importexport' stamp: 'JohanBrichau 12/6/2010 16:55'!
objectsToExport 
	self subclassResponsibility ! !

!DALAbstractDAO methodsFor: 'private' stamp: 'JohanBrichau 1/6/2011 08:21'!
privateSession: aSession
	session := aSession! !

!DALAbstractDAO methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 20:42'!
registrationOperation: aBlock forObject: anObject
	^ session registrationOperation: aBlock forObject: anObject! !

!DALAbstractDAO methodsFor: 'db operations' stamp: 'AndyKellens 12/14/2010 20:54'!
rollback 
	session rollback! !

!DALAbstractDAO methodsFor: 'db operations' stamp: 'AndyKellens 12/14/2010 20:37'!
root
	^session root! !

!DALAbstractDAO methodsFor: 'db operations' stamp: 'JohanBrichau 1/25/2011 10:04'!
root: aRoot
	session root: aRoot! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'AndyKellens 10/23/2010 14:32'!
startTransaction: aTransactionBlock forObject: anObject onSuccess: aSuccessBlock onFailure: aFailureBlock
	"Executing a transaction without retry block is done by execution it with a retry block that always mentions false"
	^self 
		startTransaction: aTransactionBlock 
		forObject: anObject  
		onSuccess: aSuccessBlock 
		onFailure: aFailureBlock 
		retryIf:[false] ! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'AndyKellens 10/23/2010 14:35'!
startTransaction: aTransactionBlock forObject: anObject onSuccess: aSuccessBlock onFailure: aFailureBlock retryIf:aRetryBlock
	^self 
		startTransaction: aTransactionBlock 
		forObject: anObject 
		onSuccess: aSuccessBlock 
		onFailure: aFailureBlock 
		retryIf: aRetryBlock 
		allowNonPersistentObject: false ! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'JohanBrichau 1/26/2011 12:44'!
startTransaction: aTransactionBlock forObject: anObject onSuccess: aSuccessBlock onFailure: aFailureBlock retryIf:aRetryBlock allowNonPersistentObject: aBoolean
	"Execute a tx"
	aBoolean "Check if the object is (still) in the database"
		ifFalse:[(self isPersistentObject: anObject) ifFalse:[^aFailureBlock value]].
	
	[self executeAsTransaction: aTransactionBlock] "Execute the transaction -> this is DAO specific"
		on:(DALAbstractDAO current databaseException) do:[:e | "On failure"
					self rollback. "Bring the database back up to date"
					^aRetryBlock value 	"Check whether the transaction needs to be retried"
						ifTrue:[ "If yes, retry the transaction once more, this time passing a false as retryBlock"
							self 
								startTransaction: aTransactionBlock 
								forObject: anObject  
								onSuccess: aSuccessBlock 
								onFailure: aFailureBlock 
								retryIf:[false] 
								allowNonPersistentObject: aBoolean] 
						ifFalse:[aFailureBlock value] "If not, execute the failure block"]. 
	"If we manage to get to the end of the transaction without any problems, then execute the success block"
	^aSuccessBlock value
	! !

!DALAbstractDAO methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 20:44'!
unregistrationOperation: aBlock forObject: anObject
	^ session unregistrationOperation: aBlock forObject: anObject! !

!DALAbstractDAO methodsFor: 'transactions' stamp: 'AndyKellens 12/14/2010 20:42'!
withRetryOperation: aBlock
	"Execute a transaction that must always succeed"
	^session withRetryOperation: aBlock! !

DALAbstractDAO subclass: #DALSegmentedDAO
	instanceVariableNames: 'root segmentSymbol'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALSegmentedDAO class methodsFor: 'creation' stamp: 'JohanBrichau 1/25/2011 11:36'!
createDatabaseConnection
	self error: 'Create connection to segmented DAO with #createDatabaseConnectionForSegment:'! !

!DALSegmentedDAO class methodsFor: 'creation' stamp: 'JohanBrichau 1/26/2011 12:42'!
createDatabaseConnectionForSegment: aSymbol
	| dao |
	"Make a connection for this segment"
	dao := self basicNew.
	dao beSegment: aSymbol.
	dao initializeWithSession: (self sessionClass onDAO: dao).
	^ dao! !

!DALSegmentedDAO class methodsFor: 'creation' stamp: 'ThomasCleenewerck 4/6/2011 13:52'!
createRootDatabaseConnection
	| dao |
	"Make a connection for this segment"
	dao := self basicNew.
	dao initializeAsRootWithSession: (self sessionClass onDAO: dao).
	^ dao! !

!DALSegmentedDAO class methodsFor: 'db actions' stamp: 'JohanBrichau 1/26/2011 12:42'!
reinitializeDatabase
	| db |
	"(re)initialize the database completely"
	db := self basicNew.
	db privateSession: (self sessionClass onDAO: db).
	db createSegmentStructure.
	db disconnect! !

!DALSegmentedDAO class methodsFor: 'db actions' stamp: 'JohanBrichau 1/26/2011 12:41'!
reinitializeDatabaseForSegment: aSegmentSymbol
	| db |
	"(re)initialize the segment only"
	db := self basicNew.
	db privateSession: (self sessionClass onDAO: db).
	db beSegment: aSegmentSymbol.
	db createDatabaseStructure.
	db disconnect! !

!DALSegmentedDAO methodsFor: 'initialization' stamp: 'JohanBrichau 1/25/2011 13:51'!
beSegment: aSymbol 
	segmentSymbol := aSymbol.
	! !

!DALSegmentedDAO methodsFor: 'initialization' stamp: 'JohanBrichau 1/25/2011 11:34'!
createSegmentStructure 
	"Initialize the segment database"
	session root: self class createDictionary.
	session commit.! !

!DALSegmentedDAO methodsFor: 'initialization' stamp: 'ThomasCleenewerck 4/6/2011 13:50'!
initializeAsRootWithSession: aSession
	super initializeWithSession: aSession.
	root := session root.! !

!DALSegmentedDAO methodsFor: 'initialization' stamp: 'JohanBrichau 1/26/2011 11:46'!
initializeWithSession: aSession
	super initializeWithSession: aSession.
	root := session root at: segmentSymbol ifAbsent:[self error: 'DB segment ',segmentSymbol,' does not exist']! !

!DALSegmentedDAO methodsFor: 'testing' stamp: 'JohanBrichau 3/20/2011 15:46'!
isSegmentedDAO 
	^ true! !

!DALSegmentedDAO methodsFor: 'db operations' stamp: 'JohanBrichau 1/25/2011 10:10'!
root 
	^ root! !

!DALSegmentedDAO methodsFor: 'db operations' stamp: 'JohanBrichau 1/25/2011 10:51'!
root: aRoot
	session root at: segmentSymbol put: aRoot.
	root := aRoot! !

!DALSegmentedDAO methodsFor: 'accessing' stamp: 'JohanBrichau 3/20/2011 15:46'!
segmentSymbol
	^ segmentSymbol ! !

Object subclass: #DALNilID
	instanceVariableNames: 'oldID'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALNilID commentStamp: '<historical>' prior: 0!
(c) Copyright 2010, Inceptive bvba, http://www.inceptive.be !

!DALNilID methodsFor: 'converting' stamp: 'AndyKellens 5/2/2010 13:54'!
asNumber 
	^-1! !

!DALNilID methodsFor: 'testing' stamp: 'AndyKellens 6/24/2010 22:34'!
hash 
	^oldID hash! !

!DALNilID methodsFor: 'testing' stamp: 'AndyKellens 5/1/2010 09:50'!
isNilID
	^true! !

!DALNilID methodsFor: 'converting' stamp: 'JohanBrichau 7/8/2010 13:06'!
jsonOn: aStream 
	^ self oldID jsonOn: aStream! !

!DALNilID methodsFor: 'accessing' stamp: 'AndyKellens 6/19/2010 14:19'!
oldID
	^ oldID! !

!DALNilID methodsFor: 'accessing' stamp: 'AndyKellens 6/19/2010 14:19'!
oldID: anObject
	oldID := anObject! !

Object subclass: #DALObject
	instanceVariableNames: 'versionStamp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALObject methodsFor: 'testing' stamp: 'JohanBrichau 5/31/2011 16:14'!
isDALObject 
	^ true! !

!DALObject methodsFor: 'accessing' stamp: 'JohanBrichau 5/31/2011 15:46'!
versionStamp 
	^ versionStamp! !

Object subclass: #DALObjectIDCounter
	instanceVariableNames: 'counter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALObjectIDCounter commentStamp: '<historical>' prior: 0!
(c) Copyright 2010, Inceptive bvba, http://www.inceptive.be !

!DALObjectIDCounter class methodsFor: 'instance creation' stamp: 'AndyKellens 10/26/2009 21:22'!
new
	^super new initialize! !

!DALObjectIDCounter methodsFor: 'operations' stamp: 'AndyKellens 10/26/2009 21:22'!
counter
	^counter! !

!DALObjectIDCounter methodsFor: 'operations' stamp: 'AndyKellens 3/31/2011 19:04'!
increase
	counter := counter + 1.
	self markAsChanged:#counter.
	^counter! !

!DALObjectIDCounter methodsFor: 'operations' stamp: 'AndyKellens 12/17/2010 21:41'!
increaseWith: aNumber
	| temp |
	"Bulk creation of object IDs"
	counter := counter + 1.
	temp := counter.
	counter := counter + (aNumber - 1).
	self goodsChanged.
	^temp to: counter! !

!DALObjectIDCounter methodsFor: 'initialize-release' stamp: 'AndyKellens 10/26/2009 21:22'!
initialize
	counter := 0! !

Object subclass: #DALSession
	instanceVariableNames: 'dao'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

DALSession subclass: #DALExternalSession
	instanceVariableNames: 'nativeSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALExternalSession methodsFor: 'private' stamp: 'JohanBrichau 12/7/2010 16:05'!
createNativeSession
	self subclassResponsibility ! !

!DALExternalSession methodsFor: 'initialization' stamp: 'JohanBrichau 12/7/2010 16:05'!
initializeWithDAO: aDAO 
	super initializeWithDAO: aDAO.
	nativeSession := self createNativeSession ! !

DALSession subclass: #DALImageSession
	instanceVariableNames: 'objectsToDelete'
	classVariableNames: 'Root'
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALImageSession class methodsFor: 'factory methods' stamp: 'ThomasCleenewerck 2/8/2011 16:13'!
createBinaryFileStream: aPath
	| stream |
	stream := FileStream fileNamed: aPath.
	stream binary.
	^stream! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 15:25'!
createDictionary 
	^Dictionary new.! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'ThomasCleenewerck 2/8/2011 16:20'!
createDirectory: aPath
	^(FileDirectory on: aPath) assureExistence! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 15:25'!
createMatrix
	^Matrix new! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 15:25'!
createOrderedCollection 
	^OrderedCollection new! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:41'!
createRcDictionary 
	^Dictionary new.! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:41'!
createRcOrderedCollection 
	^OrderedCollection new! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:41'!
createRcSet
	^Set new! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 15:25'!
createSet
	^Set new! !

!DALImageSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 4/21/2011 11:13'!
createVersionStamp
	^0! !

!DALImageSession class methodsFor: 'root' stamp: 'JohanBrichau 5/7/2011 21:29'!
root 
	^ Root! !

!DALImageSession class methodsFor: 'root' stamp: 'JohanBrichau 5/7/2011 21:29'!
root: anObject
	Root := anObject! !

!DALImageSession methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 20:43'!
bringUpToDate 
! !

!DALImageSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 15:49'!
commit! !

!DALImageSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 19:30'!
disconnect 
	"Don't do anything"! !

!DALImageSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 16:08'!
executeAsTransaction: aBlock 
	aBlock value! !

!DALImageSession methodsFor: 'public' stamp: 'AndyKellens 12/15/2010 21:27'!
hasData 
	^true! !

!DALImageSession methodsFor: 'private' stamp: 'JohanBrichau 1/25/2011 14:19'!
increaseUniqueIdentifier 
	^(dao root at:#UniqueIdentifier) increase! !

!DALImageSession methodsFor: 'initialization' stamp: 'JohanBrichau 5/7/2011 21:17'!
initializeWithDAO: aDao
	objectsToDelete := Set new.
	super initializeWithDAO: aDao.
! !

!DALImageSession methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 19:17'!
registrationOperation: aBlock forObject: anObject
	"When registering an object, it could be the case that the object is actually re-registered"
	"In that case, reuse the old identifier"
	| id |
	id := (anObject uniqueIdentifier isNilID and:[anObject uniqueIdentifier oldID notNil])
		ifTrue:[anObject uniqueIdentifier oldID]
		ifFalse:[(self increaseUniqueIdentifier)].
	anObject uniqueIdentifier: id.
	aBlock value.
	self putObjectInHash: anObject! !

!DALImageSession methodsFor: 'public' stamp: 'JohanBrichau 5/7/2011 21:25'!
root 
	^ self class root! !

!DALImageSession methodsFor: 'public' stamp: 'JohanBrichau 5/7/2011 21:25'!
root: anObject 
	self class root: anObject! !

!DALImageSession methodsFor: 'private' stamp: 'JohanBrichau 5/7/2011 21:29'!
unregistrationOperation: aBlock forObject: anObject
	| newID |
	anObject uniqueIdentifier isNilID 
		ifTrue:[newID := anObject uniqueIdentifier]
		ifFalse:[
		newID := DALNilID new.
		newID oldID: (anObject uniqueIdentifier)].
	objectsToDelete add: anObject.
	aBlock value.
	self removeObjectFromHash: anObject.
	anObject uniqueIdentifier: newID! !

!DALImageSession methodsFor: 'public' stamp: 'JohanBrichau 6/3/2011 12:31'!
withRetryOperation: aBlock
	^aBlock value! !

DALImageSession subclass: #DALImageTxSession
	instanceVariableNames: 'transactionShouldFail txLevel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database-Abstraction-Layer'!

!DALImageTxSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 20:53'!
executeAsTransaction: aBlock 
	"To make it possible to test transaction, the unit test can set a
	switch on the testing DAO that makes the next transaction fail. If
	that bit is set, an Exception is raised, else the block is executed
	and its value returned."
	txLevel := txLevel + 1.
	transactionShouldFail
		ifTrue: [objectsToDelete := Set new. txLevel := 0. self class databaseException signal.]
		ifFalse: [|val | transactionShouldFail := false.
			val := aBlock value.
			txLevel := txLevel - 1.
			txLevel = 0 ifTrue:[objectsToDelete := Set new.].
			^val].
	! !

!DALImageTxSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 20:51'!
failTransaction 
	transactionShouldFail := true! !

!DALImageTxSession methodsFor: 'initialization' stamp: 'JohanBrichau 07/02/2011 11:00'!
initializeWithDAO: aDAO 
	super initializeWithDAO: aDAO.
	transactionShouldFail := false.
	txLevel := 0.! !

!DALImageTxSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 20:55'!
rollback! !

!DALImageTxSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 20:51'!
succeedTransaction 
	transactionShouldFail := false! !

!DALSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:46'!
createDictionary 
	self subclassResponsibility ! !

!DALSession class methodsFor: 'instance creation' stamp: 'ThomasCleenewerck 2/8/2011 16:19'!
createDirectory: aPath
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:47'!
createOrderedCollection
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:40'!
createRcDictionary 
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:40'!
createRcOrderedCollection
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'AndyKellens 12/14/2010 20:40'!
createRcSet
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:47'!
createSet
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 4/21/2011 11:11'!
createVersionStamp
	self subclassResponsibility ! !

!DALSession class methodsFor: 'factory methods' stamp: 'JohanBrichau 12/7/2010 14:47'!
databaseException
	self subclassResponsibility ! !

!DALSession class methodsFor: 'instance creation' stamp: 'JohanBrichau 12/7/2010 14:56'!
onDAO: aDAO
	^super new initializeWithDAO: aDAO ! !

!DALSession methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 20:43'!
bringUpToDate 
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 15:45'!
commit 
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 14:53'!
disconnect 
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 14:55'!
executeAsTransaction: aTransactionBlock
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'AndyKellens 12/15/2010 21:26'!
hasData
	self subclassResponsibility ! !

!DALSession methodsFor: 'private' stamp: 'JohanBrichau 12/7/2010 16:10'!
increaseUniqueIdentifier 
	self subclassResponsibility ! !

!DALSession methodsFor: 'initialization' stamp: 'JohanBrichau 12/7/2010 16:05'!
initializeWithDAO: aDAO
	dao := aDAO.! !

!DALSession methodsFor: 'private' stamp: 'JohanBrichau 1/25/2011 13:37'!
putObjectInHash: anObject
	(dao root at:#ObjectHash) at: (anObject uniqueIdentifier) put: anObject! !

!DALSession methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 19:12'!
registrationOperation: aBlock forObject: anObject
	self subclassResponsibility  ! !

!DALSession methodsFor: 'private' stamp: 'JohanBrichau 1/25/2011 13:59'!
removeObjectFromHash: anObject
	(dao root at:#ObjectHash) removeKey: (anObject uniqueIdentifier) ifAbsent:[]! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 15:05'!
rollback
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 15:00'!
root 
	self subclassResponsibility ! !

!DALSession methodsFor: 'public' stamp: 'JohanBrichau 12/7/2010 15:42'!
root: anObject
	self subclassResponsibility ! !

!DALSession methodsFor: 'private' stamp: 'AndyKellens 12/14/2010 19:12'!
unregistrationOperation: aBlock forObject: anObject
	self subclassResponsibility  ! !

!DALSession methodsFor: 'public' stamp: 'AndyKellens 12/14/2010 19:23'!
withRetryOperation: aBlock
	self subclassResponsibility ! !

!Object methodsFor: '*database-abstraction-layer' stamp: 'JohanBrichau 5/31/2011 16:14'!
isDALObject 
	^ false! !

!Object methodsFor: '*database-abstraction-layer' stamp: 'AndyKellens 6/4/2011 09:30'!
isNilID
	^false! !

!Object methodsFor: '*database-abstraction-layer' stamp: 'JohanBrichau 5/31/2011 20:41'!
markAsChanged: aSymbol
	"do nothing"! !

!Collection methodsFor: '*database-abstraction-layer' stamp: 'JohanBrichau 8/19/2011 22:14'!
isDALObject 
	self flag: 'hm...'.
	^ true! !
